{% extends "granadilla/base.html" %}
{% load granadilla_tags %}
{% load i18n %}

{% block subtitle %}{% trans "Devices" %}{% endblock %}

{% block breadcrumbs %}
<a href="{% url "granadilla.views.index" %}">{% granadilla_title %}</a> &rsaquo; {% trans "Devices" %}
{% endblock %}

{% block content %}
<h2>{% trans "Device details" %}</h2>

<table class="phonebook">
  <tbody>
    <tr>
      <th>{% trans "Owner" %}</th>
      <td>{{ device.owner_username }}</td>
    </tr>
    <tr>
      <th>{% trans "Name" %}</th>
      <td>{{ device.name }}</td>
    </tr>
    <tr>
      <th>{% trans "Login" %}</th>
      <td>{{ device.login }}</td>
    </tr>
    <tr>
      <th>{% trans "Password" %}</th>
      <td><a href="{% url "granadilla.views.device_password" device.login %}">{% trans "Regenerate password" %}</a></td>
    </tr>
  </tbody>
</table>

{% endblock %}
